<template>
  <el-card shadow="never" class="aui-card--fill">
    <div class="mod-app">
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-input v-model="dataForm.dictName" :placeholder="$t('prodParamMz.dictName')" clearable></el-input>
        </el-form-item>
        <el-form-item>
          <el-input v-model="dataForm.dictCode" :placeholder="$t('prodParamMz.dictCode')" clearable></el-input>
        </el-form-item>
        <el-form-item>
          <el-button @click="getDataList()">{{ $t('query') }}</el-button>
        </el-form-item>
      </el-form>
      <el-table
          v-loading="dataListLoading"
          :data="dataList"
          border
          @selection-change="dataListSelectionChangeHandle"
          @sort-change="dataListSortChangeHandle"
          style="width: 100%;">
        <el-table-column type="selection" header-align="center" align="center" width="50"></el-table-column>
        <el-table-column prop="dictName" :label="$t('prodParamMz.dictName')" header-align="center" align="center"></el-table-column>
        <el-table-column prop="dictCode" :label="$t('prodParamMz.dictCode')" header-align="center" align="center"></el-table-column>
        <el-table-column prop="description" :label="$t('prodParamMz.description')" header-align="center" align="center"></el-table-column>
        <el-table-column :label="$t('handle')" fixed="right" header-align="center" align="center" width="160">
          <template slot-scope="scope">
            <el-button type="text" size="small" @click="menuConfig(scope.row)">煤种列表</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination
          :current-page="page"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="limit"
          :total="total"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="pageSizeChangeHandle"
          @current-change="pageCurrentChangeHandle">
      </el-pagination>
      <!-- 弹窗, 配置菜单 -->
      <dict-item v-if="dictItemVisible" ref="dictItem" @refreshDataList="getDataList"></dict-item>
    </div>
  </el-card>
</template>

<script>
import mixinViewModule from '@/mixins/view-module'
import DictItem from './item'
export default {
  mixins: [mixinViewModule],
  data () {
    return {
      mixinViewModuleOptions: {
        getDataListURL: '/iailab-iems-system/sys/dict/page',
        getDataListIsPage: true
      },
      dataForm: {
        dictCodeList: 'ymmz,cpmz,cpkc'
      },
      dictItemVisible: false
    }
  },
  components: {
    DictItem
  },
  methods: {
    // 菜单配置
    menuConfig (row) {
      this.dictItemVisible = true
      this.$nextTick(() => {
        this.$refs.dictItem.init(row.id, row.dictCode)
      })
    }
  }
}
</script>
